#! /usr/bin/env python
"""Add a bookmark to the database

This file is a part of Bookmarks database and Internet robot.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2002-2014 PhiloSoft Design"
__license__ = "GNU GPL"

import sys, os, time
from bkmk_objects import Bookmark
from robots import robot


def run():
   from getopt import getopt
   optlist, args = getopt(sys.argv[1:], "t:")

   report_stats = 1
   title = ''

   for _opt, _arg in optlist:
      if _opt == '-s':
         report_stats = 0
      elif _opt == '-t':
         title = _arg
   try:
      del _opt, _arg
   except NameError:
      pass

   if len(args) <> 1:
      sys.stderr.write("bkmk-add: too many or too few arguments\n")
      sys.stderr.write("Usage: bkmk-add [-s] [-t title] url\n")
      sys.exit(1)

   from storage import storage, import_storage
   storage = storage()

   if report_stats:
      sys.stdout.write("Loading %s: " % storage.filename)
      sys.stdout.flush()

   root_folder = storage.load()

   if report_stats:
      print "Ok"

   href = args[0]
   now = int(time.time())
   bookmark = Bookmark(href, str(now), '0', '0')
   bookmark.name = ''
   bookmark.parent = None

   global robot
   robot = robot(None)

   if robot.check_url(bookmark): # get real title and last modified date
      if title: # forced title
         bookmark.name = title
      elif hasattr(bookmark, "real_title"):
         bookmark.name = bookmark.real_title
      if report_stats:
         sys.stdout.write("Adding %s with title '%s'\n" % (href, bookmark.name))
      del bookmark.parent
      root_folder.append(bookmark)

      if report_stats:
         sys.stdout.write("Storing %s: " % storage.filename)
         sys.stdout.flush()

      storage.store(root_folder)

      if report_stats:
         print "Ok"


if __name__ == '__main__':
   run()
